.. include:: includes.rst

While Loop Rules
----------------

while_loop_001
##############

This rule has been moved to **iteration_scheme_300**.

while_loop_002
##############

This rule has been moved to **loop_statement_302**.
